-- iChatAutoLocationStatus
-- Copyright (C)  2010, 2013 Stuart Cheshire
-- email: iChatAutoLocationStatus@stuartcheshire.org
-- Written August 2010
-- Updated November 2013

using terms from application "Messages"
	on login finished for theService
		-- iChat service "theService" is an instance of class icsv
		-- (get service type of theService) is AIM/Bonjour/Jabber
		-- display dialog (get name of theService) -- Name as it appears in iChat Accounts list

		-- Find out where we are
		set NetworkFingerprint to (do shell script "echo show State:/Network/Service/.\\*/IPv\\[46\\] pattern | scutil | grep NetworkSignature")
		
		-- Find out if the user has configured an iChat status message they'd like for this location
		-- To find new network fingerprints to add to this section, in a Terminal window run the command:
		-- echo show State:/Network/Service/.\*/IPv\[46\] pattern | scutil | grep NetworkSignature
		set NewLocation to ""
		if NetworkFingerprint contains "IPv4.Router=17.12.34.56" then
			set NewLocation to "At Apple"
		else if NetworkFingerprint contains "IPv4.Router=10.0.1.1;IPv4.RouterHardwareAddress=00:1f:xx:xx:xx:xx" then
			set NewLocation to "At home"
		else if NetworkFingerprint contains "IPv4.Router=192.168.99.1;IPv4.RouterHardwareAddress=00:16:xx:xx:xx:xx" then
			set NewLocation to "Somewhere else"
		end if

		-- We can also customize the status based on day of the week and/or time of day, etc.
		if NewLocation contains "At home" then
			if (weekday of (current date)) is in {Monday, Tuesday, Wednesday, Thursday, Friday} then
				if (hours of (current date)) is in {7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18} then
					set NewLocation to "Working from home"
				end if
			end if
		end if

		-- If the user's current status message already contains the new location name (e.g. the new location is
		-- "At Apple" and the user's current status message says "At Apple, in a meeting") then we don't change it.
		-- Note: we have to explicitly check that NewLocation is not empty, because although the string "abc"
		-- contains the substrings "ab" and "a", AppleScript does not consider it to contain the empty string "".
		-- We'd like "OldStatus does not contain empty string" to be always false, but it's not in AppleScript.
		set OldStatus to (get status message of theService)
		if NewLocation is not "" and OldStatus does not contain NewLocation then
			set status to available
			set status message to NewLocation
		else
			--display dialog "Current Status " & OldStatus & " already contains " & NewLocation & ""
		end if
		--display dialog "Done login finished"
	end login finished
	
	# The following are unused but need to be defined to avoid crashing Messages.app
	
	on received text invitation theText from theBuddy for theChat
	end received text invitation
	
	on received audio invitation theText from theBuddy for theChat
	end received audio invitation
	
	on received video invitation theText from theBuddy for theChat
	end received video invitation
	
	on received remote screen sharing invitation from theBuddy for theChat
	end received remote screen sharing invitation
	
	on received local screen sharing invitation from theBuddy for theChat
	end received local screen sharing invitation
	
	on received file transfer invitation theFileTransfer
	end received file transfer invitation
	
	on buddy authorization requested theRequest
	end buddy authorization requested
	
	on message sent theMessage for theChat
	end message sent
	
	on message received theMessage from theBuddy for theChat
	end message received
	
	on chat room message received theMessage from theBuddy for theChat
	end chat room message received
	
	on active chat message received theMessage
	end active chat message received
	
	on addressed chat room message received theMessage from theBuddy for theChat
	end addressed chat room message received
	
	on addressed message received theMessage from theBuddy for theChat
	end addressed message received
	
	on av chat started
	end av chat started
	
	on av chat ended
	end av chat ended
	
	on logout finished for theService
	end logout finished
	
	on buddy became available theBuddy
	end buddy became available
	
	on buddy became unavailable theBuddy
	end buddy became unavailable
	
	on completed file transfer
	end completed file transfer
	
end using terms from
